==> pegasus-merchandise-api-2.0.7-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpProdDynmAuditLogCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: OpProductVO.java, v 0.1 2015-08-14 17:13
 */
public class OpProdDynmAuditLogCond extends BaseQueryCond {


    private Long id;

    private String auditLogId;

    private String prodCode;

    private String skuCode; 
    
    private String auditStatus;

    private List<String> onShelfChnCodes;

    private Date updateDateStart;

    private Date updateDateEnd;

    private String flag = "Y";


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAuditLogId() {
        return auditLogId;
    }

    public void setAuditLogId(String auditLogId) {
        this.auditLogId = auditLogId;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(String auditStatus) {
        this.auditStatus = auditStatus;
    }

    public List<String> getOnShelfChnCodes() {
        return onShelfChnCodes;
    }

    public void setOnShelfChnCodes(List<String> onShelfChnCodes) {
        this.onShelfChnCodes = onShelfChnCodes;
    }

    public Date getUpdateDateStart() {
        return updateDateStart;
    }

    public void setUpdateDateStart(Date updateDateStart) {
        this.updateDateStart = updateDateStart;
    }

    public Date getUpdateDateEnd() {
        return updateDateEnd;
    }

    public void setUpdateDateEnd(Date updateDateEnd) {
        this.updateDateEnd = updateDateEnd;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }

}

==> pegasus-merchandise-api-4.0.11-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpProdDynmAuditLogCond.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

/**
 * @author Roy.Chen
 * @version $Id: OpProductVO.java, v 0.1 2015-08-14 17:13
 */
public class OpProdDynmAuditLogCond extends BaseQueryCond {


    private Long id;

    private String auditLogId;

    private String prodCode;

    private String skuCode; 
    
    private String auditStatus;

    private List<String> onShelfChnCodes;

    private Date updateDateStart;

    private Date updateDateEnd;

    private String flag = "Y";


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getAuditLogId() {
        return auditLogId;
    }

    public void setAuditLogId(String auditLogId) {
        this.auditLogId = auditLogId;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public String getSkuCode() {
        return skuCode;
    }

    public void setSkuCode(String skuCode) {
        this.skuCode = skuCode;
    }

    public String getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(String auditStatus) {
        this.auditStatus = auditStatus;
    }

    public List<String> getOnShelfChnCodes() {
        return onShelfChnCodes;
    }

    public void setOnShelfChnCodes(List<String> onShelfChnCodes) {
        this.onShelfChnCodes = onShelfChnCodes;
    }

    public Date getUpdateDateStart() {
        return updateDateStart;
    }

    public void setUpdateDateStart(Date updateDateStart) {
        this.updateDateStart = updateDateStart;
    }

    public Date getUpdateDateEnd() {
        return updateDateEnd;
    }

    public void setUpdateDateEnd(Date updateDateEnd) {
        this.updateDateEnd = updateDateEnd;
    }

    public String getFlag() {
        return flag;
    }

    public void setFlag(String flag) {
        this.flag = flag;
    }

}
